import { Compiler, ShaderNode } from './compiler';
import { FloatNode, IRgbaNode, IRgbNode, IVec3Node, IVec4Node, RgbaNode } from './types';
export declare class SelectorNode<T> implements ShaderNode<string> {
    private readonly other;
    private readonly selector;
    constructor(other: ShaderNode<T>, selector: (out: T) => string);
    compile(c: Compiler): {
        out: string;
    };
}
export declare class Vec3ComponentsNode implements ShaderNode<{
    readonly x: string;
    readonly y: string;
    readonly z: string;
}> {
    private readonly vec;
    constructor(vec: IVec3Node);
    compile(c: Compiler): {
        chunk: string;
        out: {
            x: string;
            y: string;
            z: string;
        };
    };
    get x(): SelectorNode<{
        x: string;
        y: string;
        z: string;
    }>;
    get y(): SelectorNode<{
        x: string;
        y: string;
        z: string;
    }>;
    get z(): SelectorNode<{
        x: string;
        y: string;
        z: string;
    }>;
    get outputs(): {
        x: SelectorNode<{
            x: string;
            y: string;
            z: string;
        }>;
        y: SelectorNode<{
            x: string;
            y: string;
            z: string;
        }>;
        z: SelectorNode<{
            x: string;
            y: string;
            z: string;
        }>;
    };
}
declare class GetFloatComponentNode extends FloatNode {
    private readonly vec;
    private readonly component;
    constructor(vec: IVec3Node, component: string);
    compile(c: Compiler): {
        out: string;
    };
}
export declare function getX(vec: IVec3Node | IVec4Node | IRgbNode | IRgbaNode): GetFloatComponentNode;
export declare function getY(vec: IVec3Node | IVec4Node | IRgbNode | IRgbaNode): GetFloatComponentNode;
export declare function getZ(vec: IVec3Node | IVec4Node | IRgbNode | IRgbaNode): GetFloatComponentNode;
export declare function getW(vec: IVec4Node | IRgbaNode): GetFloatComponentNode;
export declare class AssignNode implements ShaderNode<string> {
    private readonly name;
    private readonly node;
    constructor(name: string, node: ShaderNode<string>);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class LinearToOutputTexelNode extends RgbaNode {
    private readonly node;
    constructor(node: IRgbaNode);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export {};
